@@ -470,27 +470,12 @@ class Experiment(ExperimentSection):
         The wrapper function :func:`run_experiment_section` should be used instead of this method, if possible.
 
         """
-        logger.debug('Running {} with data {}.'.format(section.level, section.data))
+        logger.debug('Running {}.'.format(section.description))
 
-        if isinstance(from_section, int):
-            from_section = [from_section]
-        if from_section is None:
-            from_section = [1]
-        if len(from_section) > 1:
-            next_from_section = from_section[1:]
-        else:
-            next_from_section = [1]
+        from_section, next_from_section = self._parse_from_section(from_section)
 
         # Handle parent callbacks and set parent has_started to True.
-        with ExitStack() as stack:
-            if parent_callbacks:
-                logger.debug('Entering all parent levels...')
-            for parent in self.parents(section):
-                parent.has_started = True
-                if parent_callbacks:
-                    logger.debug('Entering {} with data {}...'.format(parent.level, parent.data))
-                    self.session_data[parent.level] = stack.enter_context(
-                        self.context_managers.get(parent.level, _dummy_context_manager)(self, parent))
+        with self._parent_context(section, parent_callbacks=parent_callbacks, demo=demo):
 
             # Back to the regular behavior.
             with self.context_managers.get(
@@ -501,15 +486,16 @@ class Experiment(ExperimentSection):
 
                 if section.is_bottom_level:
                     results = self.run_callback(self, section)
-                    logger.debug('Results: {}.'.format(results))
 
                     if not demo:
                         section.add_data(results)
 
                 else:  # Not bottom level.
                     for next_section in section[from_section[0]:]:
-                        self.run_section(
-                            next_section, demo=demo, parent_callbacks=False, from_section=next_from_section)
+                        self.run_section(next_section,
+                                         demo=demo,
+                                         parent_callbacks=False,
+                                         from_section=next_from_section)
 
             if not demo:
                 section.has_finished = True
@@ -523,6 +509,30 @@ class Experiment(ExperimentSection):
                 if all(child.has_finished for child in parent):
                     parent.has_finished = True
 
+    @staticmethod
+    def _parse_from_section(from_section):
+        if isinstance(from_section, int):
+            from_section = [from_section]
+        if from_section is None:
+            from_section = [1]
+        if len(from_section) > 1:
+            next_from_section = from_section[1:]
+        else:
+            next_from_section = [1]
+        return from_section, next_from_section
+
+    @contextmanager
+    def _parent_context(self, section, parent_callbacks=True, demo=False):
+        with ExitStack() as stack:
+            for parent in self.parents(section):
+                if not demo:
+                    parent.has_started = True
+                if parent_callbacks:
+                    logger.debug('Entering {} context.'.format(parent.description))
+                    self.session_data[parent.level] = stack.enter_context(
+                        self.context_managers.get(parent.level, _dummy_context_manager)(self, parent))
+            yield
+
     def resume_section(self, section, **kwargs):
         """Rerun a section that has been started but not finished, starting where running last left off.
 
