@@ -2,12 +2,9 @@
 This module contains the |ExperimentSection| class, which is imported in `__init__.py`.
 
 """
-import logging
 import collections
 import itertools
 
-logger = logging.getLogger(__name__)
-
 
 class ExperimentSection():
     """
@@ -45,6 +42,8 @@ class ExperimentSection():
     ----------
     tree : |DesignTree|
     data : |ChainMap|
+    description : str
+        The name and number of the section (e.g., ``'trial 3'``).
     dataframe : |DataFrame|
         All data associated with the |ExperimentSection| and its descendants.
     heterogeneous_design_iv_name : str
@@ -108,12 +107,26 @@ class ExperimentSection():
     def local_levels(self):
         return {child.level for child in self}
 
+    @property
+    def description(self):
+        try:
+            n = ' {}'.format(self.data[self.level])
+        except KeyError:
+            n = ''
+        return '{}{}'.format(self.level, n)
+
     def __repr__(self):
         return 'ExperimentSection({}, {})'.format(self.tree.__repr__(), self.data.__repr__())
 
     def __eq__(self, other):
         if isinstance(other, type(self)):
-            return self.__dict__ == other.__dict__
+            # Workaround pandas issue
+            # https://github.com/pydata/pandas/issues/7830
+            try:
+                return self.__dict__ == other.__dict__
+            except ValueError:
+                return False
+        return False
 
     def get_next_tree(self):
         """
@@ -197,9 +210,7 @@ class ExperimentSection():
 
         child_data = self.data.new_child()
         child_data.update(data)
-        level = tree.levels_and_designs[0].name
 
-        logger.debug('Generating {} with data {}.'.format(level, child_data))
         child = ExperimentSection(tree, child_data)
         if to_start:
             self._children.appendleft(child)
