@@ -197,3 +197,28 @@ def test_walk():
 def test_tuple_indexing():
     session = ExperimentSection(make_tree(['session', 'block', 'trial'], {}), ChainMap())
     assert session[1, 2] is session[1][2]
+
+
+def test_description():
+    block = ExperimentSection(make_tree(['block', 'trial'], {}), ChainMap())
+    assert block.description == 'block'
+    for i, trial in enumerate(block):
+        assert trial.description == 'trial {}'.format(i + 1)
+
+
+def test_section_equality_bug():
+    """Exception raised on testing section equality (while running __contains__),
+    when Section.data attributes contain DataFrames with different shapes.
+
+    """
+    blocks = [ExperimentSection(make_tree(['block', 'trial'], {}), ChainMap())
+              for _ in range(2)]
+    assert blocks[0] == blocks[1]
+    blocks[0].data['df'] = pd.DataFrame([[1, 2], [3, 4]])
+    blocks[1].data['df'] = pd.DataFrame([[1, 2], [3, 4], [5, 6]])
+    assert blocks[0] != blocks[1]
+
+
+def test_bizarre_equality():
+    block = ExperimentSection(make_tree(['block', 'trial'], {}), ChainMap())
+    assert (block == 1) is False
